ItemRendererDetails class

Details of single legend item.

Constructors

ItemRendererDetails({required int index, required String text, required Color? color, required ShapeMarkerType iconType, BorderSide? iconBorder})
Creates ItemRendererDetails.

Properties

color ↔ Color?
Particular legend icon color.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconBorder ↔ BorderSide?
Border of the icon.
getter/setter pair
iconType ↔ ShapeMarkerType
Particular legend icon type.
getter/setter pair
index → int
Index of the legend item.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Particular legend item text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited