LegendItem class

Represents the class of items in legends.

Constructors

LegendItem({required String text, Color? color, Shader? shader, ImageProvider<Object>? imageProvider, ShapeMarkerType? iconType, double? iconStrokeWidth, ShapeMarkerType? overlayMarkerType, double? degree, double? endAngle, double? startAngle})
Creates a LegendItem.
const

Properties

color → Color?
Specifies the color of the icon.
final
degree → double?
Specifies the degree for radial bar icon.
final
endAngle → double?
Specifies the end angle for radial bar icon.
final
hashCode → int
The hash code for this object.
no setterinherited
iconStrokeWidth → double?
Specifies the stroke width of the icon.
final
iconType → ShapeMarkerType?
Specifies the type of the icon.
final
imageProvider → ImageProvider<Object>?
Identifies an image.
final
overlayMarkerType → ShapeMarkerType?
Specifies the overlay marker for cartesian line type icon.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shader → Shader?
Specifies the shader of the icon.
final
startAngle → double?
Specifies the start angle for radial bar icon.
final
text → String
Specifies the text of the legend.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited