SfDataGridThemeData class
Holds the color and typography values for a SfDataGridTheme. Use this class to configure a SfDataGridTheme widget
To obtain the current theme, use SfDataGridTheme.of.
Widget build(BuildContext context) {
return Scaffold(
body: SfDataGridTheme(
data: SfDataGridThemeData(
brightness: Brightness.dark,
),
child: SfDataGrid(columns: [],
source: _dataGridSource)
),
);
}
- Mixed-in types
- Annotations
Constructors
-
SfDataGridThemeData({Color? gridLineColor, double? gridLineStrokeWidth, Color? selectionColor, DataGridCurrentCellStyle? currentCellStyle, Color? frozenPaneLineColor, double? frozenPaneLineWidth, Color? sortIconColor, Color? headerColor, Color? headerHoverColor, double? frozenPaneElevation, Color? columnResizeIndicatorColor, double? columnResizeIndicatorStrokeWidth, Color? rowHoverColor, TextStyle? rowHoverTextStyle, Widget? sortIcon, Widget? filterIcon, Color? filterIconColor, Color? filterIconHoverColor, Color? sortOrderNumberColor, Color? sortOrderNumberBackgroundColor, TextStyle? filterPopupTextStyle, TextStyle? filterPopupDisabledTextStyle, Color? columnDragIndicatorColor, double? columnDragIndicatorStrokeWidth, Widget? groupExpanderIcon, double? indentColumnWidth, Color? indentColumnColor, Color? captionSummaryRowColor, Color? filterPopupCheckColor, WidgetStateProperty<
Color?> ? filterPopupCheckboxFillColor, Color? filterPopupInputBorderColor, Color? filterPopupBackgroundColor, Color? filterPopupIconColor, Color? filterPopupDisabledIconColor, Color? advancedFilterPopupDropdownColor, Color? noMatchesFilteringLabelColor, Color? okFilteringLabelColor, Color? okFilteringLabelButtonColor, Color? cancelFilteringLabelColor, Color? cancelFilteringLabelButtonColor, Color? searchAreaFocusedBorderColor, Color? searchAreaCursorColor, Color? andRadioActiveColor, WidgetStateProperty<Color?> ? andRadioFillColor, Color? orRadioActiveColor, WidgetStateProperty<Color?> ? orRadioFillColor, Color? advancedFilterValueDropdownFocusedBorderColor, Color? advancedFilterTypeDropdownFocusedBorderColor, Color? calendarIconColor, Color? advancedFilterValueTextAreaCursorColor, Color? caseSensitiveIconColor, Color? caseSensitiveIconActiveColor, Color? advancedFilterPopupDropdownIconColor, Color? searchIconColor, Color? closeIconColor, Color? advancedFilterValueDropdownIconColor, Color? advancedFilterTypeDropdownIconColor, Color? filterPopupTopDividerColor, Color? filterPopupBottomDividerColor, Color? okFilteringLabelDisabledButtonColor, Color? appBarBottomBorderColor}) -
Create a SfDataGridThemeData that's used to configure a
SfDataGridTheme.
const
-
SfDataGridThemeData.raw({Brightness? brightness, Color? gridLineColor, double? gridLineStrokeWidth, Color? selectionColor, DataGridCurrentCellStyle? currentCellStyle, Color? frozenPaneLineColor, double? frozenPaneLineWidth, Color? sortIconColor, Color? headerHoverColor, Color? headerColor, double? frozenPaneElevation, Color? rowHoverColor, Color? columnResizeIndicatorColor, double? columnResizeIndicatorStrokeWidth, TextStyle? rowHoverTextStyle, Widget? sortIcon, Widget? filterIcon, Color? filterIconColor, Color? filterIconHoverColor, Color? sortOrderNumberColor, Color? sortOrderNumberBackgroundColor, TextStyle? filterPopupTextStyle, TextStyle? filterPopupDisabledTextStyle, Color? columnDragIndicatorColor, double? columnDragIndicatorStrokeWidth, Widget? groupExpanderIcon, double? indentColumnWidth, Color? indentColumnColor, Color? captionSummaryRowColor, Color? filterPopupCheckColor, WidgetStateProperty<
Color?> ? filterPopupCheckboxFillColor, Color? filterPopupInputBorderColor, Color? filterPopupBackgroundColor, Color? filterPopupIconColor, Color? filterPopupDisabledIconColor, Color? advancedFilterPopupDropdownColor, Color? noMatchesFilteringLabelColor, Color? okFilteringLabelColor, Color? okFilteringLabelButtonColor, Color? cancelFilteringLabelColor, Color? cancelFilteringLabelButtonColor, Color? searchAreaCursorColor, Color? searchAreaFocusedBorderColor, Color? andRadioActiveColor, WidgetStateProperty<Color?> ? andRadioFillColor, Color? orRadioActiveColor, WidgetStateProperty<Color?> ? orRadioFillColor, Color? advancedFilterValueDropdownFocusedBorderColor, Color? advancedFilterTypeDropdownFocusedBorderColor, Color? calendarIconColor, Color? advancedFilterValueTextAreaCursorColor, Color? searchIconColor, Color? closeIconColor, Color? advancedFilterPopupDropdownIconColor, Color? caseSensitiveIconActiveColor, Color? caseSensitiveIconColor, Color? advancedFilterTypeDropdownIconColor, Color? advancedFilterValueDropdownIconColor, Color? filterPopupTopDividerColor, Color? filterPopupBottomDividerColor, Color? okFilteringLabelDisabledButtonColor, Color? appBarBottomBorderColor}) -
Create a SfDataGridThemeData that's used to configure a
SfDataGridTheme.
factory
Properties
- advancedFilterPopupDropdownColor → Color?
-
The background color of the dropdown in the advanced filter popup.
final
- advancedFilterPopupDropdownIconColor → Color?
-
The color of the dropdown icon of the advanced filter popup.
final
- advancedFilterTypeDropdownFocusedBorderColor → Color?
-
The focused border color of the advanced filter type dropdown.
final
- advancedFilterTypeDropdownIconColor → Color?
-
The background color of the advanced filter type dropdown icon.
final
- advancedFilterValueDropdownFocusedBorderColor → Color?
-
The focused border color of the advanced filter value dropdown.
final
- advancedFilterValueDropdownIconColor → Color?
-
The background color of the advanced filter value dropdown icon.
final
- advancedFilterValueTextAreaCursorColor → Color?
-
The cursor color in the advanced filter value text area.
final
- andRadioActiveColor → Color?
-
The active (selected) color of the "AND" radio button.
final
-
andRadioFillColor
→ WidgetStateProperty<
Color?> ? -
The fill color of the "AND" radio button.
final
- appBarBottomBorderColor → Color?
-
The color of the bottom border of the app bar.
final
- calendarIconColor → Color?
-
The color of the calendar icon.
final
- cancelFilteringLabelButtonColor → Color?
-
The color of the cancel button in the filtering popup.
final
- cancelFilteringLabelColor → Color?
-
The color of the cancel label in the filtering popup.
final
- captionSummaryRowColor → Color?
-
The color of the caption summary row.
final
- caseSensitiveIconActiveColor → Color?
-
The active color of the case-sensitive icon.
final
- caseSensitiveIconColor → Color?
-
The default color of the case-sensitive icon.
final
- closeIconColor → Color?
-
The color of the close icon.
final
- columnDragIndicatorColor → Color?
-
The color of the column drag indicator.
final
- columnDragIndicatorStrokeWidth → double?
-
The stroke width of the column drag indicator.
final
- columnResizeIndicatorColor → Color?
-
The color of the line which indicates the column resizing.
final
- columnResizeIndicatorStrokeWidth → double?
-
The width of the line which indicates the column resizing.
final
- currentCellStyle → DataGridCurrentCellStyle?
-
Defines the default configuration of current cell in
SfDataGrid.final - filterIcon → Widget?
-
The icon to indicate the filtering applied in column.
final
- filterIconColor → Color?
-
The color of the filter icon which indicates whether
the column is filtered or not.
final
- filterIconHoverColor → Color?
-
The color for the filter icon when a pointer is hovering over it.
final
- filterPopupBackgroundColor → Color?
-
The background color of the filter popup.
final
- filterPopupBottomDividerColor → Color?
-
The color of the bottom divider in the filter popup.
final
-
filterPopupCheckboxFillColor
→ WidgetStateProperty<
Color?> ? -
The fill color of the checkbox in the filter popup.
final
- filterPopupCheckColor → Color?
-
The checkmark color of the checkbox in the filter popup.
final
- filterPopupDisabledIconColor → Color?
-
The color of disabled icons in the filter popup.
final
- filterPopupDisabledTextStyle → TextStyle?
-
The TextStyle of the disabled options in filter popup menu.
final
- filterPopupIconColor → Color?
-
The color of icons displayed in the filter popup.
final
- filterPopupInputBorderColor → Color?
-
The border color of the text field (input box) inside the filter popup.
final
- filterPopupTextStyle → TextStyle?
-
The TextStyle of the options in filter popup menu except the items
which are already selected.
final
- filterPopupTopDividerColor → Color?
-
The color of the top divider in the filter popup.
final
- frozenPaneElevation → double?
-
The elevation of the frozen pane line.
final
- frozenPaneLineColor → Color?
-
The color of the line which indicates the frozen pane.
final
- frozenPaneLineWidth → double?
-
The width of the line which indicates the frozen pane.
final
- gridLineColor → Color?
-
The color for grid line.
final
- gridLineStrokeWidth → double?
-
The width for grid line.
final
- groupExpanderIcon → Widget?
-
This icon indicates the expand-collapse state of a group in a
caption summary row.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- headerColor → Color?
-
The color for the header cells in the
SfDataGrid.final - headerHoverColor → Color?
-
The background color of header cells when a pointer is hovering over it
in
SfDataGrid.final - indentColumnColor → Color?
-
The color of an indent column.
final
- indentColumnWidth → double?
-
The width of an indent column.
final
- noMatchesFilteringLabelColor → Color?
-
The color of the "No Matches" filtering label when no results are found.
final
- okFilteringLabelButtonColor → Color?
-
The color of the OK button in the filtering popup.
final
- okFilteringLabelColor → Color?
-
The color of the OK label in the filtering popup.
final
- okFilteringLabelDisabledButtonColor → Color?
-
The color of the disabled OK button in the filtering popup.
final
- orRadioActiveColor → Color?
-
The active (selected) color of the "OR" radio button.
final
-
orRadioFillColor
→ WidgetStateProperty<
Color?> ? -
The fill color of the "OR" radio button.
final
- rowHoverColor → Color?
-
The color for the row when a pointer is hovering over it.
final
- rowHoverTextStyle → TextStyle?
-
The default TextStyle for the row when a pointer is hovering over it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchAreaCursorColor → Color?
-
The cursor color in the search area.
final
- searchAreaFocusedBorderColor → Color?
-
The focused border color of the search area.
final
- searchIconColor → Color?
-
The color of the search icon.
final
- selectionColor → Color?
-
Defines the default configuration of selection in
SfDataGrid.final - sortIcon → Widget?
-
The icon to display for sort order.
final
- sortIconColor → Color?
-
The color of the sort icon which indicates the ascending or descending
order.
final
- sortOrderNumberBackgroundColor → Color?
-
The color of the rounded background displayed
when the order of the sorting is shown.
final
- sortOrderNumberColor → Color?
-
The color of the number displayed when the order of the sorting is shown.
final
Methods
-
copyWith(
{Brightness? brightness, Color? gridLineColor, double? gridLineStrokeWidth, Color? selectionColor, DataGridCurrentCellStyle? currentCellStyle, double? frozenPaneLineWidth, Color? frozenPaneLineColor, Color? sortIconColor, Color? headerHoverColor, Color? headerColor, double? frozenPaneElevation, Color? columnResizeIndicatorColor, double? columnResizeIndicatorStrokeWidth, Color? rowHoverColor, TextStyle? rowHoverTextStyle, Widget? sortIcon, Widget? filterIcon, Color? filterIconColor, Color? filterIconHoverColor, Color? sortOrderNumberColor, Color? sortOrderNumberBackgroundColor, TextStyle? filterPopupTextStyle, TextStyle? filterPopupDisabledTextStyle, double? columnDragIndicatorStrokeWidth, Color? columnDragIndicatorColor, Widget? groupExpanderIcon, double indentColumnWidth = 40.0, Color? indentColumnColor, Color? captionSummaryRowColor, Color? filterPopupCheckColor, WidgetStateProperty< Color?> ? filterPopupCheckboxFillColor, Color? filterPopupInputBorderColor, Color? filterPopupBackgroundColor, Color? filterPopupIconColor, Color? filterPopupDisabledIconColor, Color? advancedFilterPopupDropdownColor, Color? noMatchesFilteringLabelColor, Color? okFilteringLabelColor, Color? okFilteringLabelButtonColor, Color? cancelFilteringLabelColor, Color? cancelFilteringLabelButtonColor, Color? searchAreaCursorColor, Color? searchAreaFocusedBorderColor, Color? andRadioActiveColor, WidgetStateProperty<Color?> ? andRadioFillColor, Color? orRadioActiveColor, WidgetStateProperty<Color?> ? orRadioFillColor, Color? advancedFilterTypeDropdownFocusedBorderColor, Color? advancedFilterValueDropdownFocusedBorderColor, Color? calendarIconColor, Color? advancedFilterValueTextAreaCursorColor, Color? searchIconColor, Color? closeIconColor, Color? advancedFilterPopupDropdownIconColor, Color? caseSensitiveIconActiveColor, Color? caseSensitiveIconColor, Color? advancedFilterTypeDropdownIconColor, Color? advancedFilterValueDropdownIconColor, Color? filterPopupTopDividerColor, Color? filterPopupBottomDividerColor, Color? okFilteringLabelDisabledButtonColor, Color? appBarBottomBorderColor}) → SfDataGridThemeData - Creates a copy of this theme but with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
SfDataGridThemeData? a, SfDataGridThemeData? b, double t) → SfDataGridThemeData? - Linearly interpolate between two themes.