headerHoverColor property
The background color of header cells when a pointer is hovering over it
in SfDataGrid.
Implementation
final Color? headerHoverColor;
The background color of header cells when a pointer is hovering over it
in SfDataGrid.
final Color? headerHoverColor;