animationDuration property
An animation duration which is used to animate the zoom level and actual rect property change using the given duration.
By default it will be 600 milliseconds.
Implementation
final Duration animationDuration;
An animation duration which is used to animate the zoom level and actual rect property change using the given duration.
By default it will be 600 milliseconds.
final Duration animationDuration;