child property
Specifies the child of the zoomable widget. It didn't get updated based on the zoomable widget interaction or changes.
By default it will be null.
Implementation
final Widget? child;
Specifies the child of the zoomable widget. It didn't get updated based on the zoomable widget interaction or changes.
By default it will be null.
final Widget? child;