frictionCoefficient property
In the inertial translation animation, this value is used as the coefficient of friction.
By default it will be 0.005.
Implementation
final double frictionCoefficient;
In the inertial translation animation, this value is used as the coefficient of friction.
By default it will be 0.005.
final double frictionCoefficient;